//
//  ADTPlugIn.h
//  ADT4
//
//  Created by Matheau Dakoske on Sat Mar 06 2004.
//  Copyright (c) 2004 Code Line Communications. All rights reserved.
//

#import <Cocoa/Cocoa.h>

#define ADTPlugInTypeUtility        0
#define ADTPlugInTypeTool           1

#define ADTPlugInToolbarTypeImage   0
#define ADTPlugInToolbarTypeView    1

extern NSString *ADTPlugInLoadOnLaunch;				//= @"ADTPlugInLoadOnLaunch";
extern NSString *ADTPlugInName;                     //= @"ADTPlugInName";
extern NSString *ADTPlugInMenuTitle;                //= @"ADTPlugInMenuTitle";
extern NSString *ADTPlugInToolbarType;              //= @"ADTPlugInToolbarType";
extern NSString *ADTPlugInToolbarIconFile;          //= @"ADTPlugInToolbarIconFile";
extern NSString *ADTPlugInToolbarLabel;             //= @"ADTPlugInToolbarLabel";
extern NSString *ADTPlugInToolbarPaletteLabel;      //= @"ADTPlugInToolbarPaletteLabel";
extern NSString *ADTPlugInToolbarToolTip;           //= @"ADTPlugInToolbarToolTip";
extern NSString *ADTPlugInMinimumHostVersion;       //= @"ADTPlugInMinimumHostVersion";
extern NSString *ADTPlugInHasPreferences;           //= @"ADTPlugInHasPreferences";
extern NSString *ADTPlugInRefusesGlobalAccess;      //= @"ADTPlugInRefusesGlobalAccess";
extern NSString *ADTPlugInHasMenu;					//= @"ADTPlugInHasMenu";

extern NSString *ADTPrefDefaultUnitOfMeasure;       //= @"Default unit of measure";


extern NSArray *ADTPIAllSubviewsOfView(NSView *view, BOOL traverse);

@interface ADTPlugIn : NSObject {
    
    NSBundle                    *bundle;
    NSDictionary                *attributes;
    
    NSImage                     *toolbarIcon;
    NSImage                     *prefToolbarIcon;
    
    IBOutlet NSView             *prefView;
    IBOutlet NSView             *toolbarView;
    
	NSMutableArray				*menus;
    
    NSUndoManager               *undoManager;
    id                          prevObjValue;
    
    BOOL                        willUpdateGlobalResults;
    BOOL                        nibIsLoaded;
    
    NSDictionary                *registeredDefaults;
    
}

//CLASS ACCESSORS
+ (BOOL) loadOnLaunchWithBundle:(NSBundle *)bund;
+ (int) plugInTypeWithBundle:(NSBundle *)bund;
+ (NSString *) identifierWithBundle:(NSBundle *)bund;
+ (NSString *) nameWithBundle:(NSBundle *)bund;
+ (NSString *) menuTitleWithBundle:(NSBundle *)bund;
+ (BOOL) hasPreferencesWithBundle:(NSBundle *)bund;
+ (BOOL) refusesGlobalAccessWithBundle:(NSBundle *)bund;
+ (BOOL) hasMenuWithBundle:(NSBundle *)bund;
+ (int) toolbarTypeWithBundle:(NSBundle *)bund;
+ (NSImage *) toolbarIconWithBundle:(NSBundle *)bund;
+ (NSImage *) prefToolbarIconWithBundle:(NSBundle *)bund;
+ (NSString *) toolbarLabelWithBundle:(NSBundle *)bund;
+ (NSString *) toolbarPaletteLabelWithBundle:(NSBundle *)bund;
+ (NSString *) toolbarToolTipWithBundle:(NSBundle *)bund;

//OBJECT
- (id) initWithBundlePath:(NSString *)path;
- (id) initWithBundle:(NSBundle *)bund;

//ACCESSORS
- (void) setBundle:(NSBundle *)bund;
- (NSBundle *) bundle;
- (NSDictionary *) attributes;
- (BOOL) nibIsLoaded;
- (int) plugInType;

- (NSImage *) icon;
- (NSString *) identifier;
- (NSString *) name;
- (NSString *) menuTitle;
- (int) toolbarType;
- (NSImage *) toolbarIcon;
- (NSImage *) prefToolbarIcon;
- (NSString *) toolbarLabel;
- (NSString *) toolbarPaletteLabel;
- (NSString *) toolbarToolTip;

- (NSView *) preferencesView;

- (NSMutableArray *) menus;
- (NSMenu *) menu;
- (void) removeMenu:(NSMenu *)aMenu;
- (void) refreshMenu:(NSMenu *)aMenu;
- (void) refreshMenus;

//METHODS
- (void) loadNib;

- (NSString *) preferencesIdentifier;
- (void) registerDefaults:(NSDictionary *)def;
- (NSDictionary *) registeredDefaults;
- (id) defaultsObjectForKey:(NSString *)key;
- (void) defaultsSetObject:(id)obj forKey:(NSString *)key;
- (void) defaultsSetObject:(id)obj forKey:(NSString *)key removeIfRegisteredDefault:(BOOL)remove;
- (void) defaultsSynchronize;

- (NSString *) localizeString:(NSString *)str;

- (void) closePlugIn;

- (void) setPreviousObjectValue:(id)objValue;
- (id) previousObjectValue;

@end