//
//  CLCMColor.h
//  ADT4
//
//  Created by Matheau Dakoske on Mon Sep 22 2003.
//  Copyright (c) 2003 Code Line Communications. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import <Carbon/Carbon.h>

#define CLCMColorSpaceUnkown    -1
#define CLCMColorSpaceRGB       0
#define CLCMColorSpaceCMYK      1
#define CLCMColorSpaceGray      2
#define CLCMColorSpaceLab       3
#define CLCMColorSpaceXYZ       4

//GLOBAL METHODS
extern OSType CLCMOSTypeFromCLCMColorSpace(int aColorSpace);


@interface CLCMColor : NSObject {
    NSColor *color;
    int     colorSpace;

    float   lValue;
    float   aValue;
    float   bValue;
}

//CLASS METHODS
+ (void) invalidateDefaultCMProfiles;
+ (CMProfileRef) defaultCMProfileForColorSpace:(int)aColorSpace;

+ (void) invalidateDefaultCMWorlds;
+ (CMWorldRef) defaultCMWorldForSourceColorSpace:(int)srcColorSpace destinationColorSpace:(int)destColorSpace;

//OBJECT
- (id) initWithCalibratedRed:(float)redValue green:(float)greenValue blue:(float)blueValue alpha:(float)alphaValue;
+ (CLCMColor *) colorWithCalibratedRed:(float)redValue green:(float)greenValue blue:(float)blueValue alpha:(float)alphaValue;

- (id) initWithCalibratedHue:(float)hueValue saturation:(float)saturationValue brightness:(float)brightnessValue alpha:(float)alphaValue;
+ (CLCMColor *) colorWithCalibratedHue:(float)hueValue saturation:(float)saturationValue brightness:(float)brightnessValue alpha:(float)alphaValue;

- (id) initWithCalibratedL:(float)lValue a:(float)aValue b:(float)bValue alpha:(float)alphaValue;
+ (CLCMColor *) colorWithCalibratedL:(float)lValue a:(float)aValue b:(float)bValue alpha:(float)alphaValue;

- (id) initWithDeviceCyan:(float)cyanValue magenta:(float)magentaValue yellow:(float)yellowValue black:(float)blackValue alpha:(float)alphaValue;
+ (CLCMColor *) colorWithDeviceCyan:(float)cyanValue magenta:(float)magentaValue yellow:(float)yellowValue black:(float)blackValue alpha:(float)alphaValue;

- (id) initWithCalibratedWhite:(float)whiteValue alpha:(float)alphaValue;
+ (CLCMColor *) colorWithCalibratedWhite:(float)whiteValue alpha:(float)alphaValue;

- (id) initWithColor:(NSColor *)aColor;
+ (CLCMColor *) colorWithColor:(NSColor *)aColor;

//ACCESSORS
- (void) setColorSpace:(int)aColorSpace;
- (int) colorSpace;

- (float) lComponent;
- (float) aComponent;
- (float) bComponent;

- (NSColor *) color;

//ACCESSOR METHODS
- (float) redComponent;
- (int) redComponentAsInt;
- (float) greenComponent;
- (int) greenComponentAsInt;
- (float) blueComponent;
- (int) blueComponentAsInt;

- (float) cyanComponent;
- (int) cyanComponentAsInt;
- (float) magentaComponent;
- (int) magentaComponentAsInt;
- (float) yellowComponent;
- (int) yellowComponentAsInt;
- (float) blackComponent;
- (int) blackComponentAsInt;

- (float) hueComponent;
- (int) hueComponentAsInt;
- (float) saturationComponent;
- (int) saturationComponentAsInt;
- (float) brightnessComponent;
- (int) brightnessComponentAsInt;

- (int) lComponentAsInt;
- (int) aComponentAsInt;
- (int) bComponentAsInt;

- (float) whiteComponent;
- (int) whiteComponentAsInt;

- (float) alphaComponent;
- (int) alphaComponentAsInt;

//METHODS
- (CLCMColor *) colorConvertedToColorSpace:(int)aColorSpace;

@end
